#
# spec file for package aws-c-mqtt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global library_version 1_0_0
Name:           aws-c-mqtt
Version:        0.10.6
Release:        bp160.1.9
Summary:        AWS C99 implementation of the MQTT 3.1.1 specification
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/awslabs/aws-c-mqtt
Source0:        https://github.com/awslabs/%{name}/archive/v%{version}.tar.gz
Patch0:         acm_fix-cmake-modules-path.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  cmake(aws-c-cal)
BuildRequires:  cmake(aws-c-common)
BuildRequires:  cmake(aws-c-compression)
BuildRequires:  cmake(aws-c-http)
BuildRequires:  cmake(aws-c-io)
BuildRequires:  cmake(aws-checksums)
BuildRequires:  cmake(s2n)
BuildRequires:  pkgconfig(libssl)

%description
AWS C99 implementation of the MQTT 3.1.1 specification.

%package -n lib%{name}%{library_version}
Summary:        Shared library files for aws-c-mqtt library
Group:          Development/Libraries/C and C++
Provides:       lib%{name}1 = %{version}
Obsoletes:      lib%{name}1 < %{version}

%description -n lib%{name}%{library_version}
AWS C99 implementation of the MQTT 3.1.1 specification.

This package contains the dynamically linked library.

%package bin
Summary:        Application binaries for aws-c-mqtt library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{library_version} = %{version}

%description bin
AWS C99 implementation of the MQTT 3.1.1 specification.

This package contains the application binaries.

%package devel
Summary:        Development files for aws-c-mqtt library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{library_version} = %{version}

%description devel
AWS C99 implementation of the MQTT 3.1.1 specification.

This package contains the development files.

%prep
%autosetup -p1

%build
%define __builder ninja
%cmake \
    -DCMAKE_BUILD_TYPE=Release
%make_jobs

%check
export LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build
%ctest

%install
%cmake_install

%post -n lib%{name}%{library_version} -p /sbin/ldconfig
%postun -n lib%{name}%{library_version} -p /sbin/ldconfig

%files -n lib%{name}%{library_version}
%doc README.md
%license LICENSE
%{_libdir}/*.so.1.0.0

%files bin
%{_bindir}/*

%files devel
%{_libdir}/cmake/%{name}/
%{_libdir}/*.so
%{_includedir}/*

%changelog
* Mon Sep 23 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.10.6
  * Misc request-response fixes by @bretambrose in (#375)
* Tue Sep 17 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.10.5
  * clang-format 18 by @graebm in (#371)
  * Update MacOS to arm64 by @waahm7 in (#372)
  * Final request-response polish by @bretambrose in (#367)
  * Enum reordering by @bretambrose in (#374)
* Fri May 31 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.10.4
  * Refactor MQTT5 ping timeout by @bretambrose in (#361)
  * Disabled keep alive by @bretambrose in (#363)
* Tue May 21 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.3:
  * return an error code when an mqtt5 puback has a failing reason code
* Mon Feb 26 2024 Dirk Müller <dmueller@suse.com>
- use shared library naming policy
* Wed Feb 21 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.10.2
  * Remove no-longer-necessary setup callback cross-thread task by @bretambrose in (#341)
  * Fix a bunch of places we forget to aws_raise_error() by @graebm in (#350)
  * Push ping time only if the request complete is successful by @alfred2g in (#348)
* Wed Jan  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.10.1
  * Change `port` from uint16_t to uint32_t to support VSOCK by @graebm in (#338)
* Thu Nov 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.9.10
  * Add MQTT error for subscribe failure by @sfod in (#335)
* Tue Nov 21 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.9.9
  * MQTT5 operation timeout by @bretambrose in (#333)
  * Relax validation on user-specified topic aliasing by @bretambrose in (#334)
- from version 0.9.8
  * Remove callback severance on 5-to-3 adapter by @bretambrose in (#329)
* Tue Oct 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.9.7
  * Restore negotiated settings copy by @xiazhvera in (#330)
* Fri Sep 22 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.9.6
  * Added workflow for handling answerable discussions by @yasminetalby in (#318)
  * MQTT311 compliance client behavior2 by @bretambrose in (#326)
  * Fix: coredump, dereference null variable by @alfred2g in (#327)
* Wed Aug 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.9.5
  * Explicit Private for target_link_libraries by @waahm7 in (#322)
* Tue Aug 22 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.9.4
  * Match format specifier to integer width in some
    logging by @bretambrose in (#266)
  * Address theoretical possibility of a TPS-throttled
    publish getting lost by @bretambrose in (#320)
  * Add MQTT311 on_termination callback by @sfod in (#317)
* Tue Aug 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.9.3
  * Pushoff keep alive on ack received by @xiazhvera in (#314)
  * Remove IoT core specific topic and client ID validation
    checks in MQTT5 by @bretambrose in (#315)
- from version 0.9.2
  * Fix websocket transfer callback userdata and server
    name in tls_options by @xiazhvera in (#313)
* Tue Aug  1 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.9.1
  * MQTT5 to MQTT3 adapter implementation by @bretambrose in (#312)
- from version 0.9.0
  * Run forgotten content type tests by @bretambrose in (#309)
  * MQTT311 decoder by @bretambrose in (#311)
* Thu Jul  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.14
  * Extra Connection Callbacks in 311 by @xiazhvera in (#300)
  * Adapter lifecycle take2 by @bretambrose in (#296)
* Sat Jun 10 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.13
  * Stub MQTT3-to-MQTT5 adapter by @bretambrose in (#281)
  * Use UUID for socket endpoints by @TwistedTwigleg in (#283)
  * Misc refactors involving MQTT5 needed for the MQTT3 adapter by @bretambrose in (#284)
  * Update time to ancient by @jmklix in (#287)
  * Move acquire/release to the connection vtable by @bretambrose in (#285)
  * Mqtt3-to-5 Adapter Config APIs by @bretambrose in (#286)
  * Some misc. cleanup by @bretambrose in (#292)
  * Fix cmake config by @TingDaoK in (#294)
  * Fix a bug when unsub from a non-subscribed parent topic by @xiazhvera in (#297)
  * Unit Test for #297 by @xiazhvera in (#298)
  * 311 adapter lifecycle foundations by @bretambrose in (#293)
* Tue May 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.12
  * Vtable refactor311 by @bretambrose in (#280)
  * Fix warnings in public headers by @waahm7 in (#282)
* Wed May  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.11
  * Add GitHub templates and bots by @jmklix in (#272)
  * Update builder version to fix aws-lc build on manylinux1
    by @TingDaoK in (#273)
  * Canary amazon linux by @TwistedTwigleg in (#275)
  * Add a millisecond sleep to insure tests dont share
    socket endpoints by @sbSteveK in (#276)
  * Test endpoint UUID by @sbSteveK in (#277)
  * Add const qualifier to topic alias options in
    client options for mqtt5 by @sbSteveK in (#278)
  * MQTT311 shared subscription support by @TwistedTwigleg in (#274)
  * Backed up socket fixes by @TwistedTwigleg in (#254)
  * Adjust the canary not to crash if it cannot poll
    the metric alarms by @TwistedTwigleg in (#279)
* Mon Apr 24 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.10
  * Missed actually setting the DNS override
    on MQTT311 by @bretambrose in (#270)
- from version 0.8.9
  * Resolution override by @bretambrose in (#269)
* Thu Apr  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.8
  * Update timeouts to be more container/emu-friendly by @bretambrose in (#264)
  * Adds a basic check for min reconnect delay to the
    311 reconnect test by @bretambrose in (#262)
  * A minor validation check by @xiazhvera in (#265)
  * General improvements to MQTT5 canary by @TwistedTwigleg in (#252)
  * Reconnection Backoff Fix by @bretambrose in (#267)
* Fri Feb 10 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.7
  * Port MQTT5 listener PR from staging to public by @bretambrose in (#234)
  * Add on_closed callback to MQTT311 by @TwistedTwigleg in (#258)
  * Remove upper bound checks in MQTT5 tests for now by @TwistedTwigleg in (#259)
  * Remove next_attempt_ms by @sbSteveK in (#260)
  * Add UTF8 validation check on user properties by @sbSteveK in (#256)
* Thu Jan 26 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.6
  * MQTT311 operation statistics locks by @TwistedTwigleg in (#255)
* Tue Jan 24 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.5
  * Remove temporary logging around MQTT5 decoder by @TwistedTwigleg in (#249)
  * MQTT311 operation statistics support by @TwistedTwigleg in (#247)
  * Fix and test MQTT5 decoder reset bug by @bretambrose in (#251)
* Thu Jan  5 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.4
  * Fix macro usage by @DmitriyMusatkin in (#244)
  * Tweak comment about websockets by @graebm in (#245)
  * Force channel setup failures to always execute on
    the client's event loop by @bretambrose in (#246)
* Fri Dec 23 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.3
  * Adapt to minor breaking change in websocket API by @graebm in (#243)
- from version 0.8.2
  * More debugging for MQTT5 decoder by @TwistedTwigleg in (#241)
  * Add codecov action by @TingDaoK in (#240)
  * Always rejoin session option by @bretambrose in (#242)
* Fri Dec  9 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.1
  * Decoder logging and several canary improvements by @TwistedTwigleg in (#232)
  * Private API to dump full packet byte sequences to logging by @bretambrose in (#233)
  * Do not turn on full packet logging by default by @bretambrose in (#235)
  * Make the Canary more resistant by @TwistedTwigleg in (#236)
  * More canary adjustments by @TwistedTwigleg in (#237)
  * TMP: Only print packet on error by @TwistedTwigleg in (#238)
  * Disable outbound topic aliasing by default by @bretambrose in (#239)
* Thu Dec  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.0
  * Update CI to fix downstream build by @waahm7 in (#225)
  * MQTT5 support by @TwistedTwigleg in (#227)
  * Fix zip and update canary time by @TwistedTwigleg in (#228)
  * Update canary comment to trigger CI by @TwistedTwigleg in (#229)
  * Add developer preview notice for MQTT5 at top of all public
    header files by @bretambrose in (#230)
  * Sizet stats by @bretambrose in (#231)
* Fri Nov 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.13
  * Add AppVerifier to CI by @TwistedTwigleg in (#222)
  * Log the client id going into the connect packet by @bretambrose in (#223)
  * Serialize mqtt by @bretambrose in (#224)
* Fri Sep  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.12
  * Minimum stable connection time before resetting
    reconnect timer by @sbSteveK in (#212)
  * Load cmake target fallback by @TingDaoK in #218
  * Infinite loop by @sbSteveK in (#219)
  * Removed forced cleansession behavior on a user called
    disconnect by @sbSteveK in (#220)
- from version 0.7.11
  * Update to latest builder by @bretambrose in (#209)
  * Fixed endpoint not being read in arguments by @sbSteveK in (#211)
  * No resubscribe by @bretambrose in (#215)
  * Clean up on user disconnect by @sbSteveK in (#216)
- Add rpmlint override for bogus shlib-policy-name-error
  * aws-c-mqtt-rpmlintrc
* Fri Jan  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.10
  + Remove using of try_lock
  * Try lock is not available in Windows Server 2008. Remove it from our debug build
- from version 0.7.9
  + Empty payload fixes
  * Fix a crash on Windows when the will payload was empty (precondition
    is turned into a fatal assert on Windows CD builds still)
  * Fix a decode error when receiving a message with an empty payload
- from version 0.7.8
  + Stability fix
  * Fixes a crash due to a race condition in the mqtt connection logic
- from version 0.7.7
  + Allow for null on-message callbacks in subscribe
  * Fixes a crash when the on-message callback is null for a subscription
  * Updates the public API documentation with some missing parameters and
    annotations as to what parameters can be null
- from version 0.7.6
  + Data race fixes
  * Fixes several data races related to the outstanding requests table
    and a request's timeout task.
- from version 0.7.5
  + Fix non-threadsafe hash-table accesses (take 2)
  * fix test function (#190)
- from version 0.7.4
  + Fix non-threadsafe hash-table accesses
  * Fix unsafe hash-table accesses (#189)
  * Fact: It's not safe to mutate aws_hash_table while holding an aws_hash_element.
  * Fact: `outstanding_requests_table` is accessed by multiple threads.
    We always hold a lock while accessing it.
  * Bug: There were several places where we release the lock, but continue to hold an
    aws_hash_element we got from a find() call. Once the lock is released another thread
    can mutate the `outstanding_requests_table`, leading to undefined behavior when the
    aws_hash_element is accessed again.
- from version 0.7.3
  + Direct mqtt through http proxy
  * Adds support for establishing direct mqtt connections through an http proxy
- from version 0.7.2
  + Publish payload
  * We now keep a deep copy of the publish payload. User don't need
    to keep the payload alive for the whole process.
- from version 0.7.1
  + Proxy refactor
  * Companion release to the new proxy systems in aws-c-http v0.6.2
* Thu Dec  9 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.7.0
